---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: lukasschwab
---

# Motivation
> A clear and concise description of what the problem is. For example, "I'm always frustrated when..."

# Solution
> A clear and concise description of what you want to happen.

## Considered alternatives
> A clear and concise description of any alternative solutions or features you've considered.

# Additional context
> Add any other context about the feature request here.
